==> ons-client-1.1.8-sources.jar: com/aliyun/openservices/ons/api/impl/rocketmq/ONSUtil.java <==
package com.aliyun.openservices.ons.api.impl.rocketmq;

import com.alibaba.rocketmq.common.message.MessageConst;
import com.alibaba.rocketmq.common.message.MessageExt;
import com.aliyun.openservices.ons.api.Message;
import com.aliyun.openservices.ons.api.MessageAccessor;

import java.util.*;
import java.util.Map.Entry;


public class ONSUtil {
    private static Set<String> ReservedKeySetRMQ = new HashSet<String>();

    private static Set<String> ReservedKeySetONS = new HashSet<String>();

    static {

        /**
         * RMQ
         */
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_KEYS);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_TAGS);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_WAIT_STORE_MSG_OK);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_DELAY_TIME_LEVEL);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_RETRY_TOPIC);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_REAL_TOPIC);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_REAL_QUEUE_ID);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_TRANSACTION_PREPARED);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_PRODUCER_GROUP);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_MIN_OFFSET);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_MAX_OFFSET);

        /**
         * ONS
         */
        ReservedKeySetONS.add(Message.SystemPropKey.TAG);
        ReservedKeySetONS.add(Message.SystemPropKey.KEY);
        ReservedKeySetONS.add(Message.SystemPropKey.MSGID);
        ReservedKeySetONS.add(Message.SystemPropKey.RECONSUMETIMES);
        ReservedKeySetONS.add(Message.SystemPropKey.STARTDELIVERTIME);
    }


    public static com.alibaba.rocketmq.common.message.Message msgConvert(
            com.aliyun.openservices.ons.api.Message message) {
        com.alibaba.rocketmq.common.message.Message msgRMQ =
                new com.alibaba.rocketmq.common.message.Message();
        if (message.getTopic() != null) {
            msgRMQ.setTopic(message.getTopic());
        }
        if (message.getKey() != null) {
            msgRMQ.setKeys(message.getKey());
        }
        if (message.getTag() != null) {
            msgRMQ.setTags(message.getTag());
        }
        if (message.getStartDeliverTime() > 0) {
            msgRMQ.putUserProperty(Message.SystemPropKey.STARTDELIVERTIME,
                String.valueOf(message.getStartDeliverTime()));
        }
        if (message.getBody() != null) {
            msgRMQ.setBody(message.getBody());
        }

        Properties systemProperties = MessageAccessor.getSystemProperties(message);
        if (systemProperties != null) {
            Iterator<Entry<Object, Object>> it = systemProperties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<Object, Object> next = it.next();
                if (!ReservedKeySetONS.contains(next.getKey().toString())) {
                    com.alibaba.rocketmq.common.message.MessageAccessor.putProperty(msgRMQ, next.getKey()
                        .toString(), next.getValue().toString());
                }
            }
        }

        Properties userProperties = message.getUserProperties();
        if (userProperties != null) {
            Iterator<Entry<Object, Object>> it = userProperties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<Object, Object> next = it.next();
                if (!ReservedKeySetRMQ.contains(next.getKey().toString())) {
                    com.alibaba.rocketmq.common.message.MessageAccessor.putProperty(msgRMQ, next.getKey()
                        .toString(), next.getValue().toString());
                }
            }
        }

        return msgRMQ;
    }


    public static com.aliyun.openservices.ons.api.Message msgConvert(
            com.alibaba.rocketmq.common.message.Message msgRMQ) {
        com.aliyun.openservices.ons.api.Message message = new com.aliyun.openservices.ons.api.Message();
        if (msgRMQ.getTopic() != null) {
            message.setTopic(msgRMQ.getTopic());
        }
        if (msgRMQ.getKeys() != null) {
            message.setKey(msgRMQ.getKeys());
        }
        if (msgRMQ.getTags() != null) {
            message.setTag(msgRMQ.getTags());
        }
        if (msgRMQ.getBody() != null) {
            message.setBody(msgRMQ.getBody());
        }

        message.setReconsumeTimes(((MessageExt) msgRMQ).getReconsumeTimes());

        Map<String, String> properties = msgRMQ.getProperties();
        if (properties != null) {
            Iterator<Entry<String, String>> it = properties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<String, String> next = it.next();
                // System
                if (ReservedKeySetRMQ.contains(next.getKey().toString())) {
                    MessageAccessor.putSystemProperties(message, next.getKey().toString(), next.getValue()
                        .toString());
                }
                // User
                else {
                    message.putUserProperties(next.getKey().toString(), next.getValue().toString());
                }
            }
        }

        return message;
    }
}

==> ons-client-1.2.1-sources.jar: com/aliyun/openservices/ons/api/impl/rocketmq/ONSUtil.java <==
package com.aliyun.openservices.ons.api.impl.rocketmq;

import com.alibaba.rocketmq.common.message.MessageConst;
import com.alibaba.rocketmq.common.message.MessageExt;
import com.aliyun.openservices.ons.api.Message;
import com.aliyun.openservices.ons.api.MessageAccessor;
import com.aliyun.openservices.ons.api.exception.ONSClientException;

import java.util.*;
import java.util.Map.Entry;


public class ONSUtil {
    private static Set<String> ReservedKeySetRMQ = new HashSet<String>();

    private static Set<String> ReservedKeySetONS = new HashSet<String>();


    static {

        /**
         * RMQ
         */
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_KEYS);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_TAGS);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_WAIT_STORE_MSG_OK);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_DELAY_TIME_LEVEL);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_RETRY_TOPIC);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_REAL_TOPIC);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_REAL_QUEUE_ID);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_TRANSACTION_PREPARED);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_PRODUCER_GROUP);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_MIN_OFFSET);
        ReservedKeySetRMQ.add(MessageConst.PROPERTY_MAX_OFFSET);

        /**
         * ONS
         */
        ReservedKeySetONS.add(Message.SystemPropKey.TAG);
        ReservedKeySetONS.add(Message.SystemPropKey.KEY);
        ReservedKeySetONS.add(Message.SystemPropKey.MSGID);
        ReservedKeySetONS.add(Message.SystemPropKey.RECONSUMETIMES);
        ReservedKeySetONS.add(Message.SystemPropKey.STARTDELIVERTIME);
    }


    public static com.alibaba.rocketmq.common.message.Message msgConvert(com.aliyun.openservices.ons.api.Message message) {
        com.alibaba.rocketmq.common.message.Message msgRMQ = new com.alibaba.rocketmq.common.message.Message();
        if (message == null) {
            throw new ONSClientException("\'message\' is null");
        }

        if (message.getTopic() != null) {
            msgRMQ.setTopic(message.getTopic());
        }
        if (message.getKey() != null) {
            msgRMQ.setKeys(message.getKey());
        }
        if (message.getTag() != null) {
            msgRMQ.setTags(message.getTag());
        }
        if (message.getStartDeliverTime() > 0) {
            msgRMQ.putUserProperty(Message.SystemPropKey.STARTDELIVERTIME, String.valueOf(message.getStartDeliverTime()));
        }
        if (message.getBody() != null) {
            msgRMQ.setBody(message.getBody());
        }

        Properties systemProperties = MessageAccessor.getSystemProperties(message);
        if (systemProperties != null) {
            Iterator<Entry<Object, Object>> it = systemProperties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<Object, Object> next = it.next();
                if (!ReservedKeySetONS.contains(next.getKey().toString())) {
                    com.alibaba.rocketmq.common.message.MessageAccessor.putProperty(msgRMQ, next.getKey().toString(),
                            next.getValue().toString());
                }
            }
        }

        Properties userProperties = message.getUserProperties();
        if (userProperties != null) {
            Iterator<Entry<Object, Object>> it = userProperties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<Object, Object> next = it.next();
                if (!ReservedKeySetRMQ.contains(next.getKey().toString())) {
                    com.alibaba.rocketmq.common.message.MessageAccessor.putProperty(msgRMQ, next.getKey().toString(),
                            next.getValue().toString());
                }
            }
        }

        return msgRMQ;
    }


    public static com.aliyun.openservices.ons.api.Message msgConvert(com.alibaba.rocketmq.common.message.Message msgRMQ) {
        com.aliyun.openservices.ons.api.Message message = new com.aliyun.openservices.ons.api.Message();
        if (msgRMQ.getTopic() != null) {
            message.setTopic(msgRMQ.getTopic());
        }
        if (msgRMQ.getKeys() != null) {
            message.setKey(msgRMQ.getKeys());
        }
        if (msgRMQ.getTags() != null) {
            message.setTag(msgRMQ.getTags());
        }
        if (msgRMQ.getBody() != null) {
            message.setBody(msgRMQ.getBody());
        }

        message.setReconsumeTimes(((MessageExt) msgRMQ).getReconsumeTimes());

        Map<String, String> properties = msgRMQ.getProperties();
        if (properties != null) {
            Iterator<Entry<String, String>> it = properties.entrySet().iterator();
            while (it.hasNext()) {
                Entry<String, String> next = it.next();
                // System
                if (ReservedKeySetRMQ.contains(next.getKey().toString())) {
                    MessageAccessor.putSystemProperties(message, next.getKey().toString(), next.getValue().toString());
                }
                // User
                else {
                    message.putUserProperties(next.getKey().toString(), next.getValue().toString());
                }
            }
        }

        return message;
    }
}
